@@ -5,25 +5,25 @@
 --                © 1999–2001 Daan Leijen
 -- License     :  FreeBSD
 --
--- Maintainer  :  Mark Karpov <markkarpov@opmbx.org>
+-- Maintainer  :  Mark Karpov <markkarpov92@gmail.com>
 -- Stability   :  experimental
 -- Portability :  portable
 --
 -- This module includes everything you need to get started writing a parser.
 -- If you are new to Megaparsec and don't know where to begin, take a look
--- at our tutorials <https://mrkkrp.github.io/megaparsec/tutorials.html>.
+-- at the tutorials <https://markkarpov.com/learn-haskell.html#megaparsec-tutorials>.
 --
--- By default this module is set up to parse character data. If you'd like to
--- parse the result of your own tokenizer you should start with the following
--- imports:
+-- By default this module is set up to parse character data. If you'd like
+-- to parse the result of your own tokenizer you should start with the
+-- following imports:
 --
 -- > import Text.Megaparsec.Prim
 -- > import Text.Megaparsec.Combinator
 --
 -- Then you can implement your own version of 'satisfy' on top of the
--- 'token' primitive.
+-- 'token' primitive, etc.
 --
--- Typical import section looks like this:
+-- The typical import section looks like this:
 --
 -- > import Text.Megaparsec
 -- > import Text.Megaparsec.String
@@ -32,15 +32,15 @@
 -- > -- import Text.Megaparsec.Text
 -- > -- import Text.Megaparsec.Text.Lazy
 --
--- As you can see the second import depends on data type you want to use as
--- input stream. It just defines the useful type-synonym @Parser@.
+-- As you can see the second import depends on the data type you want to use
+-- as input stream. It just defines the useful type-synonym @Parser@.
 --
 -- Megaparsec 5 uses some type-level machinery to provide flexibility
 -- without compromising on type safety. Thus type signatures are sometimes
 -- necessary to avoid ambiguous types. If you're seeing a error message that
 -- reads like “Ambiguous type variable @e0@ arising from … prevents the
 -- constraint @(ErrorComponent e0)@ from being resolved”, you need to give
--- an explicit signature to your parser to eliminate the ambiguity. It's a
+-- an explicit signature to your parser to resolve the ambiguity. It's a
 -- good idea to provide type signatures for all top-level definitions.
 --
 -- Megaparsec is capable of a lot. Apart from this standard functionality
@@ -70,6 +70,8 @@ module Text.Megaparsec
   , A.optional
   -- $optional
   , unexpected
+  , match
+  , region
   , failure
   , (<?>)
   , label
@@ -157,6 +159,7 @@ module Text.Megaparsec
   , getInput
   , setInput
   , getPosition
+  , getNextTokenPosition
   , setPosition
   , pushPosition
   , popPosition
@@ -202,13 +205,13 @@ import Text.Megaparsec.Prim
 --
 -- @some p@ applies the parser @p@ /one/ or more times and returns a list of
 -- the returned values of @p@. The note about behavior of the combinator in
--- case when @p@ fails consuming input (see 'A.many') applies to 'some' as
--- well.
+-- the case when @p@ fails consuming input (see 'A.many') applies to 'some'
+-- as well.
 --
 -- > word = some letter
 
 -- $optional
 --
--- @optional p@ tries to apply parser @p@. It will parse @p@ or nothing. It
--- only fails if @p@ fails after consuming input. On success result of @p@
--- is returned inside of 'Just', on failure 'Nothing' is returned.
+-- @optional p@ tries to apply the parser @p@. It will parse @p@ or nothing.
+-- It only fails if @p@ fails after consuming input. On success result of
+-- @p@ is returned inside of 'Just', on failure 'Nothing' is returned.
