@@ -5,7 +5,7 @@
 --                © 1999–2001 Daan Leijen
 -- License     :  FreeBSD
 --
--- Maintainer  :  Mark Karpov <markkarpov@opmbx.org>
+-- Maintainer  :  Mark Karpov <markkarpov92@gmail.com>
 -- Stability   :  experimental
 -- Portability :  non-portable
 --
@@ -21,6 +21,7 @@
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
 {-# LANGUAGE MultiParamTypeClasses      #-}
 {-# LANGUAGE RankNTypes                 #-}
+{-# LANGUAGE RecordWildCards            #-}
 {-# LANGUAGE ScopedTypeVariables        #-}
 {-# LANGUAGE TupleSections              #-}
 {-# LANGUAGE TypeFamilies               #-}
@@ -37,10 +38,13 @@ module Text.Megaparsec.Prim
   , MonadParsec (..)
   , (<?>)
   , unexpected
+  , match
+  , region
     -- * Parser state combinators
   , getInput
   , setInput
   , getPosition
+  , getNextTokenPosition
   , setPosition
   , pushPosition
   , popPosition
@@ -110,7 +114,7 @@ import Data.Word (Word)
 ----------------------------------------------------------------------------
 -- Data types
 
--- | This is Megaparsec's state, it's parametrized over stream type @s@.
+-- | This is the Megaparsec's state, it's parametrized over stream type @s@.
 
 data State s = State
   { stateInput :: s
@@ -130,12 +134,7 @@ instance NFData s => NFData (State s)
 instance Arbitrary a => Arbitrary (State a) where
   arbitrary = State
     <$> arbitrary
-    <*>
-#if !MIN_VERSION_QuickCheck(2,9,0)
-      (NE.fromList . getNonEmpty <$> arbitrary)
-#else
-      arbitrary
-#endif
+    <*> (NE.fromList . getNonEmpty <$> arbitrary)
     <*> choose (1, 10000)
     <*> (unsafePos <$> choose (1, 20))
 
@@ -147,8 +146,7 @@ instance Arbitrary a => Arbitrary (State a) where
 
 data Reply e s a = Reply (State s) Consumption (Result (Token s) e a)
 
--- | This data structure represents an aspect of result of parser's
--- work.
+-- | This data structure represents an aspect of result of parser's work.
 --
 -- See also: 'Result', 'Reply'.
 
@@ -156,8 +154,7 @@ data Consumption
   = Consumed -- ^ Some part of input stream was consumed
   | Virgin   -- ^ No input was consumed
 
--- | This data structure represents an aspect of result of parser's
--- work.
+-- | This data structure represents an aspect of result of parser's work.
 --
 -- See also: 'Consumption', 'Reply'.
 
@@ -224,8 +221,9 @@ accHints
 accHints hs1 c x s hs2 = c x s (hs1 <> hs2)
 {-# INLINE accHints #-}
 
--- | Replace most recent group of hints (if any) with given 'ErrorItem' (or
--- delete it if 'Nothing' is given). This is used in 'label' primitive.
+-- | Replace the most recent group of hints (if any) with the given
+-- 'ErrorItem' (or delete it if 'Nothing' is given). This is used in 'label'
+-- primitive.
 
 refreshLastHint :: Hints t -> Maybe (ErrorItem t) -> Hints t
 refreshLastHint (Hints [])     _        = Hints []
@@ -252,20 +250,24 @@ class Ord (Token s) => Stream s where
   -- | Update position in stream given tab width, current position, and
   -- current token. The result is a tuple where the first element will be
   -- used to report parse errors for current token, while the second element
-  -- is the incremented position that will be stored in parser's state.
+  -- is the incremented position that will be stored in the parser's state.
+  -- The stored (incremented) position is used whenever position can't
+  -- be\/shouldn't be updated by consuming a token. For example, when using
+  -- 'failure', we don't grab a new token (we need to fail right were we are
+  -- now), so error position will be taken from parser's state.
   --
   -- When you work with streams where elements do not contain information
-  -- about their position in input, result is usually consists of the third
-  -- argument unchanged and incremented position calculated with respect to
-  -- current token. This is how default instances of 'Stream' work (they use
-  -- 'defaultUpdatePos', which may be a good starting point for your own
-  -- position-advancing function).
+  -- about their position in input, the result is usually consists of the
+  -- third argument unchanged and incremented position calculated with
+  -- respect to current token. This is how default instances of 'Stream'
+  -- work (they use 'defaultUpdatePos', which may be a good starting point
+  -- for your own position-advancing function).
   --
-  -- When you wish to deal with stream of tokens where every token “knows”
+  -- When you wish to deal with a stream of tokens where every token “knows”
   -- its start and end position in input (for example, you have produced the
   -- stream with Happy\/Alex), then the best strategy is to use the start
-  -- position as actual element position and provide the end position of the
-  -- token as incremented one.
+  -- position as the actual element position and provide the end position of
+  -- the token as the incremented one.
   --
   -- @since 5.0.0
 
@@ -312,37 +314,7 @@ instance Stream TL.Text where
   updatePos = const defaultUpdatePos
   {-# INLINE updatePos #-}
 
--- If you're reading this, you may be interested in how Megaparsec works on
--- lower level. That's quite simple. 'ParsecT' is a wrapper around function
--- that takes five arguments:
---
---     * State. It includes input stream, position in input stream and
---     current value of tab width.
---
---     * “Consumed-OK” continuation (cok). This is a function that takes
---     three arguments: result of parsing, state after parsing, and hints
---     (see their description above). This continuation is called when
---     something has been consumed during parsing and result is OK (no error
---     occurred).
---
---     * “Consumed-error” continuation (cerr). This function is called when
---     some part of input stream has been consumed and parsing resulted in
---     an error. This continuation takes 'ParseError' and state information
---     at the time error occurred.
---
---     * “Empty-OK” continuation (eok). The function takes the same
---     arguments as “consumed-OK” continuation. “Empty-OK” is called when no
---     input has been consumed and no error occurred.
---
---     * “Empty-error” continuation (eerr). The function is called when no
---     input has been consumed, but nonetheless parsing resulted in an
---     error. Just like “consumed-error”, the continuation takes
---     'ParseError' record and state information.
---
--- You call specific continuation when you want to proceed in that specific
--- branch of control flow.
-
--- | @Parsec@ is non-transformer variant of more general 'ParsecT'
+-- | @Parsec@ is a non-transformer variant of the more general 'ParsecT'
 -- monad transformer.
 
 type Parsec e s = ParsecT e s Identity
@@ -359,6 +331,18 @@ newtype ParsecT e s m a = ParsecT
       -> (ParseError (Token s) e -> State s -> m b) -- empty-error
       -> m b }
 
+instance (ErrorComponent e, Stream s, Semigroup a)
+    => Semigroup (ParsecT e s m a) where
+  (<>) = A.liftA2 (<>)
+  {-# INLINE (<>) #-}
+
+instance (ErrorComponent e, Stream s, Monoid a)
+    => Monoid (ParsecT e s m a) where
+  mempty = pure mempty
+  {-# INLINE mempty #-}
+  mappend = A.liftA2 mappend
+  {-# INLINE mappend #-}
+
 instance Functor (ParsecT e s m) where
   fmap = pMap
 
@@ -421,8 +405,6 @@ pFail msg = ParsecT $ \s@(State _ pos _ _) _ _ _ eerr ->
   where d = E.singleton (representFail msg)
 {-# INLINE pFail #-}
 
--- | Low-level creation of the 'ParsecT' type.
-
 mkPT :: Monad m => (State s -> m (Reply e s a)) -> ParsecT e s m a
 mkPT k = ParsecT $ \s cok cerr eok eerr -> do
   (Reply s' consumption result) <- k s
@@ -487,8 +469,8 @@ pPlus m n = ParsecT $ \s cok cerr eok eerr ->
   in unParser m s cok cerr eok meerr
 {-# INLINE pPlus #-}
 
--- | From two states, return the one with greater number of processed
--- tokens. If the numbers of processed tokens are equal, prefer the latter
+-- | From two states, return the one with the greater number of processed
+-- tokens. If the numbers of processed tokens are equal, prefer the second
 -- state.
 
 longestMatch :: State s -> State s -> State s
@@ -511,7 +493,7 @@ instance MonadTrans (ParsecT e s) where
 class (ErrorComponent e, Stream s, A.Alternative m, MonadPlus m)
     => MonadParsec e s m | m -> e s where
 
-  -- | The most general way to stop parsing and report 'ParseError'.
+  -- | The most general way to stop parsing and report a 'ParseError'.
   --
   -- 'unexpected' is defined in terms of this function:
   --
@@ -538,24 +520,24 @@ class (ErrorComponent e, Stream s, A.Alternative m, MonadPlus m)
   hidden = label ""
 
   -- | The parser @try p@ behaves like parser @p@, except that it backtracks
-  -- parser state when @p@ fails (either consuming input or not).
+  -- the parser state when @p@ fails (either consuming input or not).
   --
   -- This combinator is used whenever arbitrary look ahead is needed. Since
   -- it pretends that it hasn't consumed any input when @p@ fails, the
   -- ('A.<|>') combinator will try its second alternative even when the
   -- first parser failed while consuming input.
   --
-  -- For example, here is a parser that is supposed to parse word “let” or
-  -- “lexical”:
+  -- For example, here is a parser that is supposed to parse the word “let”
+  -- or the word “lexical”:
   --
   -- >>> parseTest (string "let" <|> string "lexical") "lexical"
   -- 1:1:
   -- unexpected "lex"
   -- expecting "let"
   --
-  -- What happens here? First parser consumes “le” and fails (because it
+  -- What happens here? The first parser consumes “le” and fails (because it
   -- doesn't see a “t”). The second parser, however, isn't tried, since the
-  -- first parser has already consumed some input! @try@ fixes this behavior
+  -- first parser has already consumed some input! 'try' fixes this behavior
   -- and allows backtracking to work:
   --
   -- >>> parseTest (try (string "let") <|> string "lexical") "lexical"
@@ -569,10 +551,11 @@ class (ErrorComponent e, Stream s, A.Alternative m, MonadPlus m)
   -- unexpected "le"
   -- expecting "let" or "lexical"
   --
-  -- Please note that as of Megaparsec 4.4.0, 'string' backtracks
+  -- __Please note__ that as of Megaparsec 4.4.0, 'string' backtracks
   -- automatically (see 'tokens'), so it does not need 'try'. However, the
   -- examples above demonstrate the idea behind 'try' so well that it was
-  -- decided to keep them.
+  -- decided to keep them. You still need to use 'try' when your
+  -- alternatives are complex, composite parsers.
 
   try :: m a -> m a
 
@@ -584,17 +567,17 @@ class (ErrorComponent e, Stream s, A.Alternative m, MonadPlus m)
 
   lookAhead :: m a -> m a
 
-  -- | @notFollowedBy p@ only succeeds when parser @p@ fails. This parser
-  -- /never consumes/ any input and /never modifies/ parser state. It can be
-  -- used to implement the “longest match” rule.
+  -- | @notFollowedBy p@ only succeeds when the parser @p@ fails. This
+  -- parser /never consumes/ any input and /never modifies/ parser state. It
+  -- can be used to implement the “longest match” rule.
 
   notFollowedBy :: m a -> m ()
 
   -- | @withRecovery r p@ allows continue parsing even if parser @p@ fails.
-  -- In this case @r@ is called with actual 'ParseError' as its argument.
-  -- Typical usage is to return value signifying failure to parse this
-  -- particular object and to consume some part of input up to start of next
-  -- object.
+  -- In this case @r@ is called with the actual 'ParseError' as its
+  -- argument. Typical usage is to return a value signifying failure to
+  -- parse this particular object and to consume some part of the input up
+  -- to the point where the next object starts.
   --
   -- Note that if @r@ fails, original error message is reported as if
   -- without 'withRecovery'. In no way recovering parser @r@ can influence
@@ -607,8 +590,8 @@ class (ErrorComponent e, Stream s, A.Alternative m, MonadPlus m)
     -> m a             -- ^ Original parser
     -> m a             -- ^ Parser that can recover from failures
 
-  -- | @observing p@ allows to “observe” failure of @p@ parser, should it
-  -- happen, without actually ending parsing, but instead getting the
+  -- | @observing p@ allows to “observe” failure of the @p@ parser, should
+  -- it happen, without actually ending parsing, but instead getting the
   -- 'ParseError' in 'Left'. On success parsed value is returned in 'Right'
   -- as usual. Note that this primitive just allows you to observe parse
   -- errors as they happen, it does not backtrack or change how the @p@
@@ -649,7 +632,7 @@ class (ErrorComponent e, Stream s, A.Alternative m, MonadPlus m)
     -> Maybe (Token s) -- ^ Token to report when input stream is empty
     -> m a
 
-  -- | The parser @tokens test@ parses list of tokens and returns it.
+  -- | The parser @tokens test@ parses a list of tokens and returns it.
   -- Supplied predicate @test@ is used to check equality of given and parsed
   -- tokens.
   --
@@ -658,10 +641,10 @@ class (ErrorComponent e, Stream s, A.Alternative m, MonadPlus m)
   -- > string = tokens (==)
   --
   -- Note that beginning from Megaparsec 4.4.0, this is an auto-backtracking
-  -- primitive, which means that if it fails, it never consumes any
-  -- input. This is done to make its consumption model match how error
-  -- messages for this primitive are reported (which becomes an important
-  -- thing as user gets more control with primitives like 'withRecovery'):
+  -- primitive, which means that if it fails, it never consumes any input.
+  -- This is done to make its consumption model match how error messages for
+  -- this primitive are reported (which becomes an important thing as user
+  -- gets more control with primitives like 'withRecovery'):
   --
   -- >>> parseTest (string "abc") "abd"
   -- 1:1:
@@ -680,11 +663,11 @@ class (ErrorComponent e, Stream s, A.Alternative m, MonadPlus m)
        -- ^ List of tokens to parse
     -> m [Token s]
 
-  -- | Returns the full parser state as a 'State' record.
+  -- | Return the full parser state as a 'State' record.
 
   getParserState :: m (State s)
 
-  -- | @updateParserState f@ applies function @f@ to the parser state.
+  -- | @updateParserState f@ applies the function @f@ to the parser state.
 
   updateParserState :: (State s -> State s) -> m ()
 
@@ -714,7 +697,7 @@ pFailure us ps xs = ParsecT $ \s@(State _ pos _ _) _ _ _ eerr ->
 pLabel :: String -> ParsecT e s m a -> ParsecT e s m a
 pLabel l p = ParsecT $ \s cok cerr eok eerr ->
   let el = Label <$> NE.nonEmpty l
-      cl = Label . (NE.fromList "rest of " <>) <$> NE.nonEmpty l
+      cl = Label . (NE.fromList "the rest of " <>) <$> NE.nonEmpty l
       cok' x s' hs = cok x s' (refreshLastHint hs cl)
       eok' x s' hs = eok x s' (refreshLastHint hs el)
       eerr'    err = eerr err
@@ -866,20 +849,55 @@ pUpdateParserState :: (State s -> State s) -> ParsecT e s m ()
 pUpdateParserState f = ParsecT $ \s _ _ eok _ -> eok () (f s) mempty
 {-# INLINE pUpdateParserState #-}
 
--- | A synonym for 'label' in form of an operator.
+-- | A synonym for 'label' in the form of an operator.
 
 infix 0 <?>
 
 (<?>) :: MonadParsec e s m => m a -> String -> m a
 (<?>) = flip label
 
--- | The parser @unexpected item@ always fails with an error message telling
--- about unexpected item @item@ without consuming any input.
+-- | The parser @unexpected item@ fails with an error message telling about
+-- unexpected item @item@ without consuming any input.
 
 unexpected :: MonadParsec e s m => ErrorItem (Token s) -> m a
 unexpected item = failure (E.singleton item) E.empty E.empty
 {-# INLINE unexpected #-}
 
+-- | Return both the result of a parse and the list of tokens that were
+-- consumed during parsing. This relies on the change of the
+-- 'stateTokensProcessed' value to evaluate how many tokens were consumed.
+--
+-- @since 5.3.0
+
+match :: MonadParsec e s m => m a -> m ([Token s], a)
+match p = do
+  tp  <- getTokensProcessed
+  s   <- getInput
+  r   <- p
+  tp' <- getTokensProcessed
+  return (streamTake (tp' - tp) s, r)
+
+-- | Specify how to process 'ParseError's that happen inside of this
+-- wrapper. As a side effect of the current implementation changing
+-- 'errorPos' with this combinator will also change the final 'statePos' in
+-- the parser state.
+--
+-- @since 5.3.0
+
+region :: MonadParsec e s m
+  => (ParseError (Token s) e -> ParseError (Token s) e)
+     -- ^ How to process 'ParseError's
+  -> m a               -- ^ The “region” that processing applies to
+  -> m a
+region f m = do
+  r <- observing m
+  case r of
+    Left err -> do
+      let ParseError {..} = f err
+      updateParserState $ \st -> st { statePos = errorPos }
+      failure errorUnexpected errorExpected errorCustom
+    Right x -> return x
+
 -- | Make a singleton non-empty list from a value.
 
 nes :: a -> NonEmpty a
@@ -907,6 +925,17 @@ setInput s = updateParserState (\(State _ pos tp w) -> State s pos tp w)
 getPosition :: MonadParsec e s m => m SourcePos
 getPosition = NE.head . statePos <$> getParserState
 
+-- | Get the position where the next token in the stream begins. If the
+-- stream is empty, return 'Nothing'.
+--
+-- @since 5.3.0
+
+getNextTokenPosition :: forall e s m. MonadParsec e s m => m (Maybe SourcePos)
+getNextTokenPosition = do
+  State {..} <- getParserState
+  let f = fst . updatePos (Proxy :: Proxy s) stateTabWidth (NE.head statePos)
+  return (f . fst <$> uncons stateInput)
+
 -- | @setPosition pos@ sets the current source position to @pos@.
 --
 -- See also: 'getPosition', 'pushPosition', 'popPosition', and 'SourcePos'.
@@ -915,9 +944,8 @@ setPosition :: MonadParsec e s m => SourcePos -> m ()
 setPosition pos = updateParserState $ \(State s (_:|z) tp w) ->
   State s (pos:|z) tp w
 
--- | Push given position into stack of positions and continue parsing
--- working with this position. Useful for working with include files and the
--- like.
+-- | Push a position into stack of positions and continue parsing working
+-- with this position. Useful for working with include files and the like.
 --
 -- See also: 'getPosition', 'setPosition', 'popPosition', and 'SourcePos'.
 --
@@ -927,9 +955,9 @@ pushPosition :: MonadParsec e s m => SourcePos -> m ()
 pushPosition pos = updateParserState $ \(State s z tp w) ->
   State s (NE.cons pos z) tp w
 
--- | Pop a position from stack of positions unless it only contains one
--- element (in that case stack of positions remains the same). This is how
--- to return to previous source file after 'pushPosition'.
+-- | Pop a position from the stack of positions unless it only contains one
+-- element (in that case the stack of positions remains the same). This is
+-- how to return to previous source file after 'pushPosition'.
 --
 -- See also: 'getPosition', 'setPosition', 'pushPosition', and 'SourcePos'.
 --
@@ -941,14 +969,14 @@ popPosition = updateParserState $ \(State s z tp w) ->
     Nothing -> State s z  tp w
     Just z' -> State s z' tp w
 
--- | Get number of tokens processed so far.
+-- | Get the number of tokens processed so far.
 --
 -- @since 5.2.0
 
 getTokensProcessed :: MonadParsec e s m => m Word
 getTokensProcessed = stateTokensProcessed <$> getParserState
 
--- | Set number of tokens processed so far.
+-- | Set the number of tokens processed so far.
 --
 -- @since 5.2.0
 
@@ -956,20 +984,21 @@ setTokensProcessed :: MonadParsec e s m => Word -> m ()
 setTokensProcessed tp = updateParserState $ \(State s pos _ w) ->
   State s pos tp w
 
--- | Return tab width. Default tab width is equal to 'defaultTabWidth'. You
--- can set different tab width with help of 'setTabWidth'.
+-- | Return the tab width. The default tab width is equal to
+-- 'defaultTabWidth'. You can set a different tab width with the help of
+-- 'setTabWidth'.
 
 getTabWidth :: MonadParsec e s m => m Pos
 getTabWidth = stateTabWidth <$> getParserState
 
--- | Set tab width. If argument of the function is not positive number,
--- 'defaultTabWidth' will be used.
+-- | Set tab width. If the argument of the function is not a positive
+-- number, 'defaultTabWidth' will be used.
 
 setTabWidth :: MonadParsec e s m => Pos -> m ()
 setTabWidth w = updateParserState $ \(State s pos tp _) ->
   State s pos tp w
 
--- | @setParserState st@ set the full parser state to @st@.
+-- | @setParserState st@ sets the parser state to @st@.
 
 setParserState :: MonadParsec e s m => State s -> m ()
 setParserState st = updateParserState (const st)
@@ -997,14 +1026,14 @@ parse
   -> Either (ParseError (Token s) e) a
 parse = runParser
 
--- | @parseMaybe p input@ runs parser @p@ on @input@ and returns result
--- inside 'Just' on success and 'Nothing' on failure. This function also
--- parses 'eof', so if the parser doesn't consume all of its input, it will
--- fail.
+-- | @parseMaybe p input@ runs the parser @p@ on @input@ and returns the
+-- result inside 'Just' on success and 'Nothing' on failure. This function
+-- also parses 'eof', so if the parser doesn't consume all of its input, it
+-- will fail.
 --
 -- The function is supposed to be useful for lightweight parsing, where
 -- error messages (and thus file name) are not important and entire input
--- should be parsed. For example it can be used when parsing of single
+-- should be parsed. For example it can be used when parsing of a single
 -- number according to specification of its format is desired.
 
 parseMaybe :: (ErrorComponent e, Stream s) => Parsec e s a -> s -> Maybe a
@@ -1013,7 +1042,7 @@ parseMaybe p s =
     Left  _ -> Nothing
     Right x -> Just x
 
--- | The expression @parseTest p input@ applies a parser @p@ against input
+-- | The expression @parseTest p input@ applies the parser @p@ against input
 -- @input@ and prints the result to stdout. Useful for testing.
 
 parseTest :: ( ShowErrorComponent e
@@ -1028,7 +1057,7 @@ parseTest p input =
     Left  e -> putStr (parseErrorPretty e)
     Right x -> print x
 
--- | @runParser p file input@ runs parser @p@ on the input list of tokens
+-- | @runParser p file input@ runs parser @p@ on the input stream of tokens
 -- @input@, obtained from source @file@. The @file@ is only used in error
 -- messages and may be the empty string. Returns either a 'ParseError'
 -- ('Left') or a value of type @a@ ('Right').
@@ -1265,7 +1294,7 @@ fixs' _ (Right (b,s,w)) = (Right b, s, w)
 -- Debugging
 
 -- | @dbg label p@ parser works exactly like @p@, but when it's evaluated it
--- prints information useful for debugging. The @label@ is only used to
+-- also prints information useful for debugging. The @label@ is only used to
 -- refer to this parser in the debugging output. This combinator uses the
 -- 'trace' function from "Debug.Trace" under the hood.
 --
@@ -1274,17 +1303,17 @@ fixs' _ (Right (b,s,w)) = (Right b, s, w)
 -- print-out. As of current version, this combinator prints all available
 -- information except for /hints/, which are probably only interesting to
 -- the maintainer of Megaparsec itself and may be quite verbose to output in
--- general. Let me know if you would like to be able to see hints as part of
+-- general. Let me know if you would like to be able to see hints in the
 -- debugging output.
 --
 -- The output itself is pretty self-explanatory, although the following
--- abbreviations should be clarified (they are derived from low-level source
--- code):
+-- abbreviations should be clarified (they are derived from the low-level
+-- source code):
 --
---     * @COK@ — “consumed OK”. The parser consumed input and succeeded.
---     * @CERR@ — “consumed error”. The parser consumed input and failed.
---     * @EOK@ — “empty OK”. The parser succeeded without consuming input.
---     * @EERR@ — “empty error”. The parser failed without consuming input.
+--     * @COK@—“consumed OK”. The parser consumed input and succeeded.
+--     * @CERR@—“consumed error”. The parser consumed input and failed.
+--     * @EOK@—“empty OK”. The parser succeeded without consuming input.
+--     * @EERR@—“empty error”. The parser failed without consuming input.
 --
 -- Finally, it's not possible to lift this function into some monad
 -- transformers without introducing surprising behavior (e.g. unexpected
@@ -1318,7 +1347,7 @@ dbg lbl p = ParsecT $ \s cok cerr eok eerr ->
         l (DbgEERR (streamTake (streamDelta s s') (stateInput s)) err)
   in unParser p s cok' cerr' eok' eerr'
 
--- | Single piece of info to be rendered with 'dbgLog'.
+-- | A single piece of info to be rendered with 'dbgLog'.
 
 data DbgItem s e a
   = DbgIn   [Token s]
@@ -1367,13 +1396,13 @@ streamDelta
   -> Word              -- ^ Number of consumed tokens
 streamDelta s0 s1 = stateTokensProcessed s1 - stateTokensProcessed s0
 
--- | Extract given number of tokens from the stream.
+-- | Extract a given number of tokens from the stream.
 
 streamTake :: Stream s => Word -> s -> [Token s]
 streamTake n s = genericTake n (unfold s)
 
--- | Custom version of 'unfold' that matches signature of 'uncons' method in
--- 'Stream' type class we use.
+-- | A custom version of 'unfold' that matches signature of the 'uncons'
+-- method in the 'Stream' type class we use.
 
 unfold :: Stream s => s -> [Token s]
 unfold s = case uncons s of
