@@ -1,31 +1,3 @@
---
--- Tests for Megaparsec's primitive parser combinators.
---
--- Copyright © 2015–2017 Megaparsec contributors
---
--- Redistribution and use in source and binary forms, with or without
--- modification, are permitted provided that the following conditions are
--- met:
---
--- * Redistributions of source code must retain the above copyright notice,
---   this list of conditions and the following disclaimer.
---
--- * Redistributions in binary form must reproduce the above copyright
---   notice, this list of conditions and the following disclaimer in the
---   documentation and/or other materials provided with the distribution.
---
--- THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS “AS IS” AND ANY
--- EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
--- WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
--- DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
--- DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
--- DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
--- OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
--- HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
--- STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
--- ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
--- POSSIBILITY OF SUCH DAMAGE.
-
 {-# LANGUAGE CPP               #-}
 {-# LANGUAGE FlexibleContexts  #-}
 {-# LANGUAGE FlexibleInstances #-}
@@ -44,6 +16,7 @@ import Control.Monad.Identity
 import Control.Monad.Reader
 import Data.Char (toUpper, chr)
 import Data.Foldable (asum, concat)
+import Data.Function (on)
 import Data.List (isPrefixOf, foldl')
 import Data.List.NonEmpty (NonEmpty (..))
 import Data.Maybe (fromMaybe, listToMaybe, isJust)
@@ -70,6 +43,7 @@ import qualified Control.Monad.Writer.Strict as S
 import qualified Data.ByteString.Char8       as B
 import qualified Data.ByteString.Lazy.Char8  as BL
 import qualified Data.List.NonEmpty          as NE
+import qualified Data.Semigroup              as G
 import qualified Data.Set                    as E
 import qualified Data.Text                   as T
 import qualified Data.Text.Lazy              as TL
@@ -198,6 +172,37 @@ spec = do
                ( st { statePos = apos }
                , Left (err apos $ utoks (take (il + 1) stateInput) <> etoks ts) )
 
+    describe "getNextTokenPosition" $ do
+      context "when input stream is empty" $
+        it "returns Nothing" $
+          property $ \st' -> do
+            let p :: CustomParser (Maybe SourcePos)
+                p = getNextTokenPosition
+                st = (st' :: State [Span]) { stateInput = [] }
+            runParser' p st `shouldBe` (st, Right Nothing)
+      context "when input stream is not empty" $
+        it "return the position of start of the next token" $
+           property $ \st' h -> do
+             let p :: CustomParser (Maybe SourcePos)
+                 p = getNextTokenPosition
+                 st = st' { stateInput = h : stateInput st' }
+             runParser' p st `shouldBe` (st, (Right . Just . spanStart) h)
+
+  describe "ParsecT Semigroup instance" $
+    it "the associative operation works" $
+      property $ \a b -> do
+        let p = pure [a] G.<> pure [b]
+        prs p "" `shouldParse` ([a,b] :: [Int])
+
+  describe "ParsecT Monoid instance" $ do
+    it "mempty works" $ do
+      let p = mempty
+      prs p "" `shouldParse` ([] :: [Int])
+    it "mappend works" $
+      property $ \a b -> do
+        let p = pure [a] `mappend` pure [b]
+        prs p "" `shouldParse` ([a,b] :: [Int])
+
   describe "ParsecT Functor instance" $ do
     it "obeys identity law" $
       property $ \n ->
@@ -518,6 +523,41 @@ spec = do
             , errorExpected   = E.empty
             , errorCustom     = E.empty })
 
+    describe "match" $
+      it "return consumed tokens along with the result" $
+        property $ \str -> do
+          let p  = match (string str)
+          prs  p str `shouldParse`     (str,str)
+          prs' p str `succeedsLeaving` ""
+
+    describe "region" $ do
+      context "when inner parser succeeds" $
+        it "has no effect" $
+          property $ \st e n -> do
+            let p :: Parser Int
+                p = region (const e) (pure n)
+            runParser' p st `shouldBe` (st, Right (n :: Int))
+      context "when inner parser fails" $
+        it "the given function is used on the parse error" $
+          property $ \st e0 e1 -> do
+            let p :: Parser Int
+                p = region f $ failure
+                  (errorUnexpected e0)
+                  (errorExpected   e0)
+                  (errorCustom     e0)
+                f x = ParseError
+                  { errorPos        = ((G.<>)  `on` errorPos)        x e1
+                  , errorUnexpected = (E.union `on` errorUnexpected) x e1
+                  , errorExpected   = (E.union `on` errorExpected)   x e1
+                  , errorCustom     = (E.union `on` errorCustom)     x e1 }
+                r = ParseError
+                  { errorPos        = finalPos
+                  , errorUnexpected = (E.union `on` errorUnexpected) e0 e1
+                  , errorExpected   = (E.union `on` errorExpected)   e0 e1
+                  , errorCustom     = (E.union `on` errorCustom)     e0 e1 }
+                finalPos = statePos st G.<> errorPos e1
+            runParser' p st `shouldBe` (st { statePos = finalPos }, Left r)
+
     describe "failure" $
       it "signals correct parse error" $
         property $ \us ps xs -> do
@@ -540,12 +580,12 @@ spec = do
               grs  p s (`shouldFailWith` err (posN (1 :: Int) s) mempty)
               grs' p s (`failsLeaving` "")
         context "inner parser produces hints" $
-          it "replaces the last hint with “rest of <label>”" $
+          it "replaces the last hint with “the rest of <label>”" $
             property $ \lbl a -> not (null lbl) ==> do
               let p :: MonadParsec Dec String m => m String
                   p = label lbl (many (char a)) <* empty
                   s = [a]
-              grs  p s (`shouldFailWith` err (posN (1 :: Int) s) (elabel $ "rest of " ++ lbl))
+              grs  p s (`shouldFailWith` err (posN (1 :: Int) s) (elabel $ "the rest of " ++ lbl))
               grs' p s (`failsLeaving` "")
       context "when inner parser consumes and fails" $
         it "reports parse error without modification" $
@@ -1461,11 +1501,7 @@ instance Arbitrary Span where
     start <- arbitrary
     end   <- arbitrary `suchThat` (> start)
     Span start end <$>
-#if !MIN_VERSION_QuickCheck(2,9,0)
       (NE.fromList . getNonEmpty <$> arbitrary)
-#else
-      arbitrary
-#endif
 
 instance ShowToken Span where
   showTokens ts = concat (NE.toList . spanBody <$> ts)
